@@ -4,7 +4,7 @@ from steam_nb_api.ledet.ParametersLEDET import *
 import pandas as pd
 from steam_nb_api.ledet.Simulation import RunSimulations
 from steam_nb_api.ledet.SimulationEvaluation import EvaluateSimulations
-from steam_nb_api.ledet.SimulationEvaluation import QuenchPlanAnalysis
+from steam_nb_api.ledet.QuenchAnalysis import QuenchPlanAnalysis
 from steam_nb_api.ledet.AutomaticSweep import AutomaticSweep
 import time
 
@@ -20,21 +20,24 @@ testfile9 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXV\MC
 testfile10 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXV\MCBXV_CopperWedges_0.xlsx"
 testfile11 = "C:\cernbox\TEMP2\MCBY_1AP_CopperWedges_ThCool_29.xlsx"
 testfile12 = "C:\cernbox\LEDET\LEDET\MCBY_1AP_CopperWedges_ThCool\Input\MCBY_1AP_CopperWedges_ThCool_35.xlsx"
+testfile13 = "C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_23.xlsx"
 
-ledetFolder = 'C:\cernbox\LEDET\\'
-ledetExe = 'LEDET_v1_07_02_02_25May2020.exe'
+ledetFolder = 'C:\\cernbox\\LEDET_MT\\'
+ledetExe = 'LEDET_v1_08_03.exe'
 
 def CompleteRun():
     start = time.time()
     a = ParametersLEDET()
-    a.readLEDETExcel(testfile2)
-    Sw = MinMaxSweep(a, 2)
-    MagnetName = 'MBRB'
+    a.readLEDETExcel(testfile13)
+    Sw = MinMaxSweep(a, 6)
+    MagnetName = 'MQXFS4b'
+
+    ##MQXF
+    Sw.addParameterToSweep('tau_increaseRis', 0.001, 0.1)
+    Sw.addParameterToSweep('f_ro_eff_inGroup', 0.75, 3)
+    Sw.addParameterToSweep('tau_increaseRif', 0.001, 0.1)
+
 
-    ##8mag
-    # Sw.addParameterToSweep('l_magnet', 2.56, 4.8)
-    # Sw.addParameterToSweep('f_ro_eff_inGroup', 1, 3)
-    # Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
     ##13mag
     # Sw.addParameterToSweep('l_magnet', 4.16, 5.2)
     # Sw.addParameterToSweep('f_ro_eff_inGroup', 1, 3)
@@ -65,13 +68,13 @@ def CompleteRun():
     # Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
 
     ## Current Sweep
-    Sw.addCurrentSweep(6650, 30)
+    # Sw.addCurrentSweep(6650, 30)
 
     Sw.generatePermutations()
     end = time.time()
     print("Time:", end-start)
     start = time.time()
-    Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP2\\",OffsetNumber=0)
+    # Sw.prepareSimulation(MagnetName, "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Input\\",OffsetNumber=100)
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MBRC\\Input\\")
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCD\\Input\\")
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCO\\Input\\")
@@ -87,7 +90,9 @@ def CompleteRun():
     print("Time:", end - start)
     print("Preparation done")
 
-    # RunSimulations(ledetFolder, ledetExe, MagnetName, RunSimulations=False)
+    # SimNumbers = np.linspace(100,315, 216).astype(int)
+
+    # RunSimulations(ledetFolder, ledetExe, MagnetName, Simulations = SimNumbers, RunSimulations=False)
     # EvaluateSimulations("C:\\cernbox\\LEDET\\LEDET\\MCO\\Output\\Txt Files", 'MCO',
     #                     'C:\\cernbox\\Validation_MCDO\\Exp Data\\RCO.A56B1_2018-03-16_PM_I_A_AutoAlign.csv',
     #                     Sw, Mat=False, SkipAlign=True)
@@ -118,6 +123,11 @@ def CompleteRun():
     #                     'MCBXH_CopperWedges_ThCool',
     #                     'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXH1.R1_2018-03-11_PM_I_ARAW.csv',
     #                     Sw, Mat=False)
+    EvaluateSimulations("C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Txt Files",
+                        MagnetName,
+                        'C:\\cernbox\\MasterThesis\\Test23_ParSweepMeas.csv',
+                        Sw, Mat=False)
+
 
 def AutomaticRun():
     LEDETFolder = 'C:\\cernbox\LEDET\\LEDET_SimulationFiles_Quench'
@@ -143,14 +153,16 @@ def testConsistencyChecks():
 
 def testvQ():
     nameFileLEDET = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MQXA\MQXA_0.xlsx"
+    # nameFileLEDET = 'C:\cernbox\LEDET_MT\LEDET\MQXFBP2\Input\MQXFBP2_10.xlsx'
     RoxieFile = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MQXA\MQXA_All_WithIron_WithSelfField.map2d"
+    # RoxieFile = "C:\cernbox\LEDET_MT\Field Maps\MQXFBP2\MQXFBP2_All_WithIron_WithSelfField.map2d"
+    # RoxieFile = "C:\\cernbox\\LEDET_MT\\Field Maps\\MQXFBP2\\"
     a = ParametersLEDET()
     a.readLEDETExcel(nameFileLEDET)
-    a.adjust_vQ(RoxieFile)
+    [vQ, l, th_con_h, delta_t_h, th_con_w, delta_t_w] = a.adjust_vQ(RoxieFile)
     return a
 
-def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim):
-    a = QuenchPlanAnalysis(FileName_TDMS, FileName_Sim)
+def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim, verbose = False):
     Coil108 = {'C108_I1_I2':[],
                'C108_I2_I3':np.concatenate((np.linspace(29, 45, 17), np.linspace(229, 245, 17))),
                'C108_I3_I4':np.concatenate((np.linspace(46, 49, 4), np.linspace(246, 249, 4))),
@@ -211,12 +223,28 @@ def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim):
                'C111_O5_O6':np.concatenate((np.linspace(367, 377, 11), np.linspace(167, 177, 11))),
                'C111_O6_O7':np.concatenate((np.linspace(151, 166, 16), np.linspace(351, 366, 16))),
                'C111_O7_O8':[]}
-    a.ProvideTurnsToCoilStructure([Coil108,Coil109,Coil110,Coil111])
-    # a.QuenchPlanAnalysis(Plot = 0)
-    # a.FindQuenchTDMS(0.1, 0.01, Plot=1)
-    a.calculateAllQuenchIntegrals()
+    a = QuenchPlanAnalysis(FileName_TDMS, FileName_Sim, verbose = verbose)
+    # a = QuenchPlanAnalysis(0, FileName_Sim)
+    # a.ProvideTurnsToCoilStructure(Coil = [Coil109,Coil110,Coil111,Coil108])
+    a.ProvideTurnsToCoilStructure(CoilCsv = 'C:\cernbox\MasterThesis\CoilStructure_MQXFS4b.csv')
+    # a.QuenchPlanAnalysis(Plot = 1)
+    # a.FindQuenchTDMS(0.1, 0.007, Plot=0)
+    a.PlotVoltageTap(Coil = 110)
+    # a.PlotVoltageTap(TapName = 'C109_I2_I3')
+    # a.calculateAllQuenchIntegrals(TDMS = 0)
+    # a.calculateAllQuenchIntegrals(SIM = 0)
     return a
 
+def PrepareSimulations():
+    PlanFile = "C:\cernbox\MasterThesis\MQFBP2 Test\MQXFBP2_QuenchPlan_Masterfile.xlsx"
+    RefFile = "C:\cernbox\MasterThesis\MQFBP2 Test\MQXFBP2_Ref_0.xlsx"
+    OutputDirectory = "C:\cernbox\TEMP"
+
+    a = QuenchPlanAnalysis(0, 0)
+    a.PrepareSimulations(PlanFile, RefFile, OutputDirectory,
+                         QHpairs=[[1,5],[2,6],[3,7],[4,8],[9,13],[10,14],[11,15],[12,16]])
+
+
 # testConsistencyChecks()
 
 # CompareLEDETParameters("C:\cernbox\MB_1.xlsx","C:\cernbox\MB_65.xlsx")
@@ -226,6 +254,9 @@ def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim):
 # CompareLEDETParameters("C:\cernbox\MasterThesis\QuenchPlans\MQXF_V2_5400.xlsx", "C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_14.xlsx")
 # CompareLEDETParameters("C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_18.xlsx", "C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_15.xlsx")
 # CompareLEDETParameters("C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXV\MCBXV_CopperWedges_ThCool_0.xlsx", "C:\cernbox\TEMP2\MCBXH_CopperWedges_ThCool_100.xlsx")
+# CompareLEDETParameters("C:\cernbox\COSIM\\600A\RCS.A45B2\Output_3\\3_LEDET\Model\LEDET\MCS\Input\MCS_0_.xlsx","C:\cernbox\SWAN_projects\steam-notebooks\steam-sing-input\\600A_Rpar\cosim_model_RCS.A45B2\LEDET_2\LEDET\MCS\Input\MCS_0.xlsx")
+# CompareLEDETParameters("C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_23.xlsx", "C:\cernbox\MQXF_V2_2924.xlsx")
+
 
 # test_readLEDETExcel()
 # test_setgetAttributes()
@@ -235,17 +266,39 @@ def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim):
 
 # CompleteRun()
 
+# PrepareSimulations()
+
 # a  = testvQ()
 
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810151854_a026(0).tdms"
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810111418_a003(0).tdms"
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810111846_a008(0).tdms"
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810101854_tb017(0).tdms"
-td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810101725_tb016(0).tdms"
+# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810101725_tb016(0).tdms"
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810171217_a041(0).tdms"
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810121049_a012(0).tdms"
-sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_3.mat"
+# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810120908_a009(0).tdms"
+# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810111541_a006(0).tdms"
+# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810171446_a042(0).tdms"
+# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810171007_a036(0).tdms"
+# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810171144_a039(0).tdms"
+td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810161600_a033(0).tdms"
+
+# sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFBP2\\Output\\Mat Files\\SimulationResults_LEDET_10.mat"
+# sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_12.mat"
+# sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_10.mat"
+# sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_27.mat"
+# sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_15.mat"
+# sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_23.mat"
+# sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_18.mat"
+# sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_3.mat"
+# sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_12.mat"
+sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_26.mat"
+
 a = testQuenchPlanAnalysis(td_data, sim_data)
+# a.ExtractFeatures()
+# a = testQuenchPlanAnalysis(0, sim_data)
+# a = testQuenchPlanAnalysis(td_data, 0)
 
 
 # a = ParametersLEDET()
